This utility function simply checks the suitability of a
data.frame or seas.sum objects for use with
seas. If x is data.frame (using seas.df.check that is
really required, is a date column, named x$date with a
class of either link{POSIXct} or link{Date}, and
one or more variables in the var columns of x.
There must be at least one finite observation in each of var,
if supplied.
These function is used within other functions, and is not intended to
be called directly.